Learn R Programming

sandbox (version 0.2.2)

measure_SAR_OSL: Measure an aliquot with the CW SAR OSL protocol

Description

The function models the time-dependent photon counts of an aliquot according to the specified CW SAR OSL (continuous wave, single aliquot regenerative dose protocol for optically stimulated luminescence) sequence and parameters. The modelling is done for each component and photon count curves are summed to return an Luminescence::RLum.Analysis object as equivalent of importing a real measurement data set to the R-package Luminescence-package.

The function uses the package RLumModel to perform the simulation of the photon count curves.

Usage

measure_SAR_OSL(aliquot, sequence, dose_rate = 0.1)

Value

Luminescence::RLum.Analysis object. Equivalent of the import result for a real world measurement file. This object can be evaluated by functions of the package Luminescence-package.

Arguments

aliquot

data.frame or a list of it, a set of grains that are assigned to an aliquot (sample subset used for measurement), i.e., the result of prepare_Aliquot.

sequence

list, definition of the SAR protocol.

dose_rate

numeric value, Dose rate of the luminescence reader, in Gy/s.

Author

Michael Dietze, GFZ Potsdam (Germany), Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)

Examples

Run this code

if (FALSE) {

## load example data set
data(sample_osl_aliquots, envir = environment())

sequence <- list(
  RegDose = c(0, 1, 2, 5, 10, 0, 1),
  TestDose = 2,
  PH = 220,
  CH = 200,
  OSL_temp = 125,
  OSL_duration = 70)

## reduce number of 
## grains to two
sample_osl_aliquots$aliquot_1 <- 
sample_osl_aliquots$aliquot_1[1:2,]

## or measure all aliquots in a row
sar_all <- measure_SAR_OSL(
 aliquot = sample_osl_aliquots,
 sequence = sequence,
 dose_rate = 0.1)
 
 }

Run the code above in your browser using DataLab