Learn R Programming

sandbox (version 0.2.2)

prepare_Aliquot: Prepare Aliquots from Sample Dataset

Description

The function consecutively fills aliquots (i.e., subsamples distributed on round carrier discs) with grains from an input sample. Remaining grains that are not enough to fill a further aliquot are discarded.

Usage

prepare_Aliquot(sample, diameter, density = 0.65)

Value

list of data.frame objects with grains organised as aliquots, i.e. list elements.

Arguments

sample

data.frame, sample object to be distributed to aliquots.

diameter

numeric value, diameter of the aliquot sample carriers in mm.

density

numeric value, packing density of the grains on the sample carrier. Default is 0.65. The packing density is unitless.

Author

Michael Dietze, GFZ Potsdam (Germany), Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)

Examples

Run this code
## load example data set
data(sample, envir = environment())

A <- prepare_Aliquot(
 sample = sample, 
 diameter = 0.1)

B <- prepare_Aliquot(
 sample = sample, 
 diameter = 1, 
 density = 0.6)
 

Run the code above in your browser using DataLab